@@ -1,4 +1,4 @@
-dispMUA.init_overlay = function()
+dispMUA.init_overlay = () =>
 {
   if ( dispMUA.bundle != null )
   {
@@ -10,7 +10,7 @@ dispMUA.init_overlay = function()
   dispMUA.loadJSON ( "dispmua-database.json" ) ;
 
   var listener = {} ;
-  listener.onStartHeaders = function(){} ;
+  listener.onStartHeaders = () => {} ;
   listener.onEndHeaders = dispMUA.loadHeaderData ;
   gMessageListeners.push ( listener ) ;
 
